@@ -2,9 +2,10 @@ from typing import NamedTuple, Tuple, Callable, ParamSpec, TypeVar, Generic
 from datetime import datetime, timezone
 
 P = ParamSpec("P")
-LogType = TypeVar('LogType', bound='Log')
-Val = TypeVar('Val')
-NewVal = TypeVar('NewVal')
+LogType = TypeVar("LogType", bound="Log")
+Val = TypeVar("Val")
+NewVal = TypeVar("NewVal")
+
 
 class Log(NamedTuple):
     datetime: datetime
@@ -13,18 +14,23 @@ class Log(NamedTuple):
     def __str__(self) -> str:
         return f'{self.__class__.__name__}("{self.datetime.strftime('%Y-%m-%dT%H:%M:%SZ')}", "{self.message}")'
 
+
 class Info(Log):
     ...
 
+
 class Debug(Log):
     ...
 
+
 class Warning(Log):
     ...
 
+
 class Error(Log):
     ...
 
+
 class Critical(Log):
     ...
 
@@ -33,9 +39,10 @@ def log(log_type: type[LogType]):
     """
     Creates a new `Log` instance with the specified message attached
     """
+
     def inner(message: str) -> LogType:
         """
-        Attach a message to the log 
+        Attach a message to the log
         """
         return log_type(datetime.now(timezone.utc), message)
 
@@ -53,6 +60,7 @@ class Trail(Generic[Val], NamedTuple):
     """
     Container type used to wrap a value with a series of `Log` type records
     """
+
     logs: Tuple[Log, ...]
     inner: Val
 
@@ -61,6 +69,7 @@ def new(*logs: LogType):
     """
     Create a new `Trail` object with the desired logs attached.
     """
+
     def get_inner(inner: Val) -> Trail[Val]:
         """
         Attach the wrapped value to the `Trail`
@@ -74,8 +83,8 @@ def append(*logs: LogType):
     """
     Append a new series of logs to a `Trail`
     """
-    def inner(trail: Trail[Val]) -> Trail[Val]:
 
+    def inner(trail: Trail[Val]) -> Trail[Val]:
         return new(*(trail.logs + logs))(trail.inner)
 
     return inner
@@ -94,13 +103,11 @@ def trail(*logs: LogType):
     This also changes the output of the function to return a `Trail` of the type returned
     by the function.
     """
+
     def inner(func: Callable[P, NewVal]):
-
         def wrapper(*args: P.args, **kwargs: P.kwargs) -> Trail[NewVal]:
-
             return new(*logs)(func(*args, **kwargs))
 
         return wrapper
 
     return inner
-
